# Temperature type with unit convertion methods
#
# The Temperature class accepts any temperature value in degrees celsius
# and can convert it to any other unit with helper methods
# @author Sille Van Landschoot <info@sillevl.be>

class Temperature

    attr_reader :temperature

    KELVIN_SHIFT = 273.15
    FAHRENHEIT_OFFSET = 32
    FAHRENHEIT_SLOPE = Rational(9,5)

    # @param temperature [Number] temperature value in degrees celsius
    def initialize temperature
        @temperature = temperature
    end

    # Return the temperature value in degrees celsius
    # @return [Number] temperature in degrees celsius
    # @example
    #   temperature = Temperature.new 12.3
    #   puts temperature.to_celsius
    def to_celsius
        temperature
    end

    def to_fahrenheit
        (to_celsius * FAHRENHEIT_SLOPE) + FAHRENHEIT_OFFSET
    end

    def to_kelvin
        to_celsius + KELVIN_SHIFT
    end
end
